@@ -25,8 +25,7 @@ class Commander:
 
         order_review()
         #self.selected_data_engine   = Selector(self.order.data_engine).task_submit()
-        self.data_profiling_result  = Analyst(self.order.df, self.order.df_name, self.order.path_to_output).task_submit()
-        print(self.data_profiling_result)
+        self.data_profiling_result  = Analyst(self.order.df, self.order.df_name, self.order.path_to_output, self.order.userPlatform).task_submit()
         self.data_auditing_result   = Auditor(self.data_profiling_result, self.order.auditing_config, self.order.path_to_output).task_submit()
         self.Visualizing_result     = Visualizer(self.data_profiling_result, self.data_auditing_result, self.order.path_to_output, self.order.report_config, self.order.auditing_config).task_submit()
 
