@@ -31,24 +31,16 @@ class Visualizer:
     def task_submit(self):
         
         def get_profile_report(self):
-            def checkPlatform():
-                userPlatform = None
-                if platform == "linux" or platform == "linux2" or platform == "darwin":
-                    userPlatform = "Linux"
-                elif platform == "win32":
-                    userPlatform = "Window"
-                return userPlatform
 
             def manageFilePath(self):
-                userPlatform               = checkPlatform()
                 profile                         = self.data_profiling_result.profile
-                if (userPlatform == 'Window'):
-                    path_to_output                  = "{}/{}".format(self.path_to_output, self.fileNameToSave)
-                    self.pathToSaveImg              = "{}/{}/img/".format(path_to_output, profile["profile_id"])
-                    self.pathToInternalMat          = os.path.abspath(pd.__file__).replace('pandas/__init__.py','sakdas')
-                    self.pathToMkDir                = "{}/{}/".format(path_to_output, profile['profile_id'])
-                    self.pathToSaveReport           = "{}/{}/report/".format(path_to_output, profile['profile_id'])
-                    self.pathToLoadTemplate         = "{}/html_template/".format(self.pathToInternalMat)
+                if (platform == 'win32'):
+                    path_to_output                  = "{}\\{}".format(self.path_to_output, self.fileNameToSave)
+                    self.pathToSaveImg              = "{}\\{}\\img\\".format(path_to_output, profile["profile_id"])
+                    self.pathToInternalMat          = os.path.abspath(pd.__file__).replace('pandas\\__init__.py','sakdas')
+                    self.pathToMkDir                = "{}\\{}\\".format(path_to_output, profile['profile_id'])
+                    self.pathToSaveReport           = "{}\\{}\\report\\".format(path_to_output, profile['profile_id'])
+                    self.pathToLoadTemplate         = "{}\\html_template\\".format(self.pathToInternalMat)
                 else:
                     self.fileNameToSave             = self.data_profiling_result.df_name.split("/")[-1].replace(".csv",'')
                     path_to_output                  = "{}/{}".format(self.path_to_output, self.fileNameToSave)
@@ -57,7 +49,7 @@ class Visualizer:
                     self.pathToMkDir                = "{}/{}/".format(path_to_output, profile['profile_id'])
                     self.pathToSaveReport           = "{}/{}/report/".format(path_to_output, profile['profile_id'])
                     self.pathToLoadTemplate         = "{}/html_template/".format(self.pathToInternalMat)
-                    
+
             def getTop5UniquePlot(profile):
                 for column in profile["column_list"]:
                     columnName = column["columnName"]
@@ -344,7 +336,7 @@ class Visualizer:
             print('Skip Visualizing')
         else:
             print('====> Start Visualizing: Dataset Profile')
-            print(pathlib.Path().absolute())
+            #print(pathlib.Path().absolute())
             begin_time = datetime.now()
             #----------------------------
             get_profile_report(self)
