@@ -7,21 +7,27 @@ from time import gmtime, strftime
 import numpy as np
 import tracemalloc
 import os
+import sys
+from sys import platform
+from .DataQualityMetric import *
 
-from sakdas.DataQualityMetric import *
-
-def buildAnalyst(df):
+def buildAnalyst(df, dfName, userPlatform):
 
     tracemalloc.start()
-    path = os.path.abspath(pd.__file__).replace('pandas/__init__.py','sakdas')
-    with open('{}/dataQualityConfig.json'.format(path)) as f:
+    path = ""
+    if (platform == "win32"):
+        path = os.path.abspath(pd.__file__).replace('pandas\\__init__.py','sakdas\\')
+    else:
+        path = os.path.abspath(pd.__file__).replace('pandas/__init__.py','sakdas/')
+
+    with open('{}dataQualityConfig.json'.format(path)) as f:
         data = json.load(f)
 
 
     profile = {}
-    sakdasVersion   = {"profile_engine" : "4.0.1"}
+    sakdasVersion   = {"profile_engine" : "4.0.11"}
     profilingId     = {"profile_id" : str(uuid.uuid4())}
-    dataName        = {"data_name" : "Test Data"}
+    dataName        = {"data_name" : dfName}
     profilingDateTime = {"profiling_datetime" : datetime.now().strftime("%Y-%m-%dT%H:%M:%S{}".format(strftime("%z", gmtime())))} 
     profile.update(sakdasVersion)
     profile.update(profilingId)
@@ -34,15 +40,6 @@ def buildAnalyst(df):
         profile.update(new)
 
     profiles = json.dumps(profile, indent=4)
-
-    #print(profiles)
-
-
-    f = open("new.json", "wt")
-    f.write(profiles)
-    f.close()
-
-
     current, peak = tracemalloc.get_traced_memory()
     #print(f"Current memory usage is {current / 10**6}MB; Peak was {peak / 10**6}MB")
     tracemalloc.stop()
